var should = require('should')
  , raven = require('../lib/client')
  , info = require('../utils/testinfo.js')
  , server = require('../lib/client')({ connection_string: info.connection_string })
  , client = server.httpClient
  ;

describe('Test Setup', function () {
  it('should ensure database exists', function (done) {
    // Testing in a database so ensure it exists
    if (server.server_db) {
      server.ensureDatabaseExists(server.server_db, function(error, result) {
        should.not.exist(error);
        should.exist(result);
        result.ok.should.be.true;
        done();
      });
    } else {
      done();
    }
  })
  it('should be able to create AlbumsByCountSold index', function(done) {
    client.put('indexes/AlbumsByCountSold',
      { },
      {"Name":null,"Map":"from album in docs.Albums\nselect new { album.CountSold };","Maps":["from album in docs.Albums\nselect new { album.CountSold };"],"Reduce":null,"TransformResults":null,"IsMapReduce":false,"IsCompiled":false,"IsTemp":false,"Stores":{},"Indexes":{},"SortOptions":{},"Analyzers":{},"Fields":[],"Type":"Map"},
      { },
      done);
  })
  it('should be able to create AlbumsByGenre index', function(done) {
    client.put('indexes/AlbumsByGenre',
      { },
      {"Name":null,"Map":"from album in docs.Albums\nwhere album.Genre != null\nselect new { Genre = album.Genre.Id }","Maps":["from album in docs.Albums\nwhere album.Genre != null\nselect new { Genre = album.Genre.Id }"],"Reduce":null,"TransformResults":null,"IsMapReduce":false,"IsCompiled":false,"IsTemp":false,"Stores":{},"Indexes":{},"SortOptions":{},"Analyzers":{},"Fields":[],"Type":"Map"},
      { },
      done);
  })
  it('should be able to create SoldAlbums index', function(done) {
    client.put('indexes/SoldAlbums',
      { },
      {"Name":null,"Map":"from order in docs.Orders\nfrom line in order.Lines\nselect new{ line.Album, line.Quantity }\n","Maps":["from order in docs.Orders\nfrom line in order.Lines\nselect new{ line.Album, line.Quantity }\n"],"Reduce":"from result in results\ngroup result by result.Album into g\nselect new{ Album = g.Key, Quantity = g.Sum(x=>x.Quantity) }\n","TransformResults":null,"IsMapReduce":true,"IsCompiled":false,"IsTemp":false,"Stores":{},"Indexes":{},"SortOptions":{},"Analyzers":{},"Fields":[],"Type":"MapReduce"},
      { },
      done);
  })
  it('should be able to create Artists index', function(done) {
    client.put('indexes/Artists', 
      { }, 
      {"Name":null,"Map":"from album in docs.Albums\nselect new { album.Artist.Id, album.Artist.Name }","Maps":["from album in docs.Albums\nselect new { album.Artist.Id, album.Artist.Name }"],"Reduce":"from artist in results\ngroup artist by new { artist.Id, artist.Name } into g\nselect new { g.Key.Id, g.Key.Name }","TransformResults":null,"IsMapReduce":true,"IsCompiled":false,"IsTemp":false,"Stores":{},"Indexes":{},"SortOptions":{},"Analyzers":{},"Fields":[],"Type":"MapReduce"},
      { },
      done);
  })
  it('should be able to create test data', function(done) {
    client.post('bulk_docs',
      { },
      [{"Key":"genres/1","Method":"PUT","Document":{"Description":"Rock and Roll is a form of rock music developed in the 1950s and 1960s. Rock music combines many kinds of music from the United States, such as country music, folk music, church music, work songs, blues and jazz.","Name":"Rock"},"Metadata":{"Raven-Entity-Name":"Genres","Last-Modified":"Sat, 15 May 2010 00:33:22 GMT","@id":"genres/1","@etag":"c6000000-00a0-bd66-11df-5fb976a148eb"}},{"Key":"genres/2","Method":"PUT","Document":{"Description":"Jazz is a type of music which was invented in the United States. Jazz music combines African-American music with European music. Some common jazz instruments include the saxophone, trumpet, piano, double bass, and drums.","Name":"Jazz"},"Metadata":{"Raven-Entity-Name":"Genres","Last-Modified":"Sat, 15 May 2010 00:33:22 GMT","@id":"genres/2","@etag":"c6000000-00a0-bd66-11df-5fb976a148ec"}},{"Key":"genres/3","Method":"PUT","Document":{"Description":"Heavy Metal is a loud, aggressive style of Rock music. The bands who play heavy-metal music usually have one or two guitars, a bass guitar and drums. In some bands, electronic keyboards, organs, or other instruments are used. Heavy metal songs are loud and powerful-sounding, and have strong rhythms that are repeated. There are many different types of Heavy Metal, some of which are described below. Heavy metal bands sometimes dress in jeans, leather jackets, and leather boots, and have long hair. Heavy metal bands sometimes behave in a dramatic way when they play their instruments or sing. However, many heavy metal bands do not like to do this.","Name":"Metal"},"Metadata":{"Raven-Entity-Name":"Genres","Last-Modified":"Sat, 15 May 2010 00:33:22 GMT","@id":"genres/3","@etag":"c6000000-00a0-bd66-11df-5fb976a148ed"}},{"Key":"genres/4","Method":"PUT","Document":{"Description":"Alternative rock is a type of rock music that became popular in the 1980s and became widely popular in the 1990s. Alternative rock is made up of various subgenres that have come out of the indie music scene since the 1980s, such as grunge, indie rock, Britpop, gothic rock, and indie pop. These genres are sorted by their collective types of punk, which laid the groundwork for alternative music in the 1970s.","Name":"Alternative"},"Metadata":{"Raven-Entity-Name":"Genres","Last-Modified":"Sat, 15 May 2010 00:33:22 GMT","@id":"genres/4","@etag":"c6000000-00a0-bd66-11df-5fb976a148ee"}},{"Key":"genres/5","Method":"PUT","Document":{"Description":"Disco is a style of pop music that was popular in the mid-1970s. Disco music has a strong beat that people can dance to. People usually dance to disco music at bars called disco clubs. The word \"disco\" is also used to refer to the style of dancing that people do to disco music, or to the style of clothes that people wear to go disco dancing. Disco was at its most popular in the United States and Europe in the 1970s and early 1980s. Disco was brought into the mainstream by the hit movie Saturday Night Fever, which was released in 1977. This movie, which starred John Travolta, showed people doing disco dancing. Many radio stations played disco in the late 1970s.","Name":"Disco"},"Metadata":{"Raven-Entity-Name":"Genres","Last-Modified":"Sat, 15 May 2010 00:33:22 GMT","@id":"genres/5","@etag":"c6000000-00a0-bd66-11df-5fb976a148ef"}},{"Key":"genres/6","Method":"PUT","Document":{"Description":"The blues is a form of music that started in the United States during the start of the 20th century. It was started by former African slaves from spirituals, praise songs, and chants. The first blues songs were called Delta blues. These songs came from the area near the mouth of the Mississippi River.","Name":"Blues"},"Metadata":{"Raven-Entity-Name":"Genres","Last-Modified":"Sat, 15 May 2010 00:33:22 GMT","@id":"genres/6","@etag":"c6000000-00a0-bd66-11df-5fb976a148f0"}},{"Key":"genres/7","Method":"PUT","Document":{"Description":"Latin American music is the music of all countries in Latin America (and the Caribbean) and comes in many varieties. Latin America is home to musical styles such as the simple, rural conjunto music of northern Mexico, the sophisticated habanera of Cuba, the rhythmic sounds of the Puerto Rican plena, the symphonies of Heitor Villa-Lobos, and the simple and moving Andean flute. Music has played an important part recently in Latin America's politics, the nueva canción movement being a prime example. Latin music is very diverse, with the only truly unifying thread being the use of Latin-derived languages, predominantly the Spanish language, the Portuguese language in Brazil, and to a lesser extent, Latin-derived creole languages, such as those found in Haiti.","Name":"Latin"},"Metadata":{"Raven-Entity-Name":"Genres","Last-Modified":"Sat, 15 May 2010 00:33:22 GMT","@id":"genres/7","@etag":"c6000000-00a0-bd66-11df-5fb976a148f1"}},{"Key":"genres/8","Method":"PUT","Document":{"Description":"Reggae is a music genre first developed in Jamaica in the late 1960s. While sometimes used in a broader sense to refer to most types of Jamaican music, the term reggae more properly denotes a particular music style that originated following on the development of ska and rocksteady.","Name":"Reggae"},"Metadata":{"Raven-Entity-Name":"Genres","Last-Modified":"Sat, 15 May 2010 00:33:22 GMT","@id":"genres/8","@etag":"c6000000-00a0-bd66-11df-5fb976a148f2"}},{"Key":"genres/9","Method":"PUT","Document":{"Description":"Pop music is a music genre that developed from the mid-1950s as a softer alternative to rock 'n' roll and later to rock music. It has a focus on commercial recording, often oriented towards a youth market, usually through the medium of relatively short and simple love songs. While these basic elements of the genre have remained fairly constant, pop music has absorbed influences from most other forms of popular music, particularly borrowing from the development of rock music, and utilizing key technological innovations to produce new variations on existing themes.","Name":"Pop"},"Metadata":{"Raven-Entity-Name":"Genres","Last-Modified":"Sat, 15 May 2010 00:33:22 GMT","@id":"genres/9","@etag":"c6000000-00a0-bd66-11df-5fb976a148f3"}},{"Key":"genres/10","Method":"PUT","Document":{"Description":"Classical music is a very general term which normally refers to the standard music of countries in the Western world. It is music that has been composed by musicians who are trained in the art of writing music (composing) and written down in music notation so that other musicians can play it. Classical music can also be described as \"art music\" because great art (skill) is needed to compose it and to perform it well. Classical music differs from pop music because it is not made just in order to be popular for a short time or just to be a commercial success.","Name":"Classical"},"Metadata":{"Raven-Entity-Name":"Genres","Last-Modified":"Sat, 15 May 2010 00:33:22 GMT","@id":"genres/10","@etag":"c6000000-00a0-bd66-11df-5fb976a148f4"}},{"Key":"albums/387","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Let There Be Rock","CountSold":0,"Artist":{"Id":"artists/1","Name":"AC/DC"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/387","@etag":"c6000000-00a0-bd66-11df-5fcfc1379a9a"}},{"Key":"albums/388","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Greatest Hits","CountSold":0,"Artist":{"Id":"artists/100","Name":"Lenny Kravitz"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/388","@etag":"c6000000-00a0-bd66-11df-5fcfc1379a9b"}},{"Key":"albums/389","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Misplaced Childhood","CountSold":0,"Artist":{"Id":"artists/102","Name":"Marillion"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/389","@etag":"c6000000-00a0-bd66-11df-5fcfc1379a9c"}},{"Key":"albums/392","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Nevermind","CountSold":0,"Artist":{"Id":"artists/110","Name":"Nirvana"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/392","@etag":"c6000000-00a0-bd66-11df-5fcfc1379a9e"}},{"Key":"albums/394","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Bark at the Moon (Remastered)","CountSold":1,"Artist":{"Id":"artists/114","Name":"Ozzy Osbourne"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/394","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aa0"}},{"Key":"albums/395","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Blizzard of Ozz","CountSold":0,"Artist":{"Id":"artists/114","Name":"Ozzy Osbourne"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/395","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aa1"}},{"Key":"albums/396","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Diary of a Madman (Remastered)","CountSold":0,"Artist":{"Id":"artists/114","Name":"Ozzy Osbourne"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/396","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aa2"}},{"Key":"albums/397","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"No More Tears (Remastered)","CountSold":0,"Artist":{"Id":"artists/114","Name":"Ozzy Osbourne"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/397","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aa3"}},{"Key":"albums/398","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Speak of the Devil","CountSold":0,"Artist":{"Id":"artists/114","Name":"Ozzy Osbourne"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/398","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aa4"}},{"Key":"albums/399","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Walking Into Clarksdale","CountSold":0,"Artist":{"Id":"artists/115","Name":"Page & Plant"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/399","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aa5"}},{"Key":"albums/400","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"The Beast Live","CountSold":0,"Artist":{"Id":"artists/117","Name":"Paul D'Ianno"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/400","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aa6"}},{"Key":"albums/401","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Live On Two Legs [Live]","CountSold":2,"Artist":{"Id":"artists/118","Name":"Pearl Jam"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/401","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aa7"}},{"Key":"albums/402","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Riot Act","CountSold":0,"Artist":{"Id":"artists/118","Name":"Pearl Jam"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/402","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aa8"}},{"Key":"albums/403","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Ten","CountSold":0,"Artist":{"Id":"artists/118","Name":"Pearl Jam"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/403","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aa9"}},{"Key":"albums/404","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Vs.","CountSold":0,"Artist":{"Id":"artists/118","Name":"Pearl Jam"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/404","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aaa"}},{"Key":"albums/405","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Dark Side Of The Moon","CountSold":0,"Artist":{"Id":"artists/120","Name":"Pink Floyd"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/405","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aab"}},{"Key":"albums/406","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"New Adventures In Hi-Fi","CountSold":0,"Artist":{"Id":"artists/124","Name":"R.E.M."}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/406","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aac"}},{"Key":"albums/407","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Raul Seixas","CountSold":0,"Artist":{"Id":"artists/126","Name":"Raul Seixas"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:55 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/407","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aad"}},{"Key":"albums/408","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"By The Way","CountSold":0,"Artist":{"Id":"artists/127","Name":"Red Hot Chili Peppers"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/408","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aae"}},{"Key":"albums/409","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Californication","CountSold":0,"Artist":{"Id":"artists/127","Name":"Red Hot Chili Peppers"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/409","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aaf"}},{"Key":"albums/410","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Retrospective I (1974-1980)","CountSold":0,"Artist":{"Id":"artists/128","Name":"Rush"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/410","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ab0"}},{"Key":"albums/411","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Maquinarama","CountSold":0,"Artist":{"Id":"artists/130","Name":"Skank"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/411","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ab1"}},{"Key":"albums/412","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"O Samba Poconé","CountSold":0,"Artist":{"Id":"artists/130","Name":"Skank"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/412","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ab2"}},{"Key":"albums/413","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"A-Sides","CountSold":0,"Artist":{"Id":"artists/132","Name":"Soundgarden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/413","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ab3"}},{"Key":"albums/414","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Core","CountSold":0,"Artist":{"Id":"artists/134","Name":"Stone Temple Pilots"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/414","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ab4"}},{"Key":"albums/415","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"[1997] Black Light Syndrome","CountSold":0,"Artist":{"Id":"artists/136","Name":"Terry Bozzio, Tony Levin & Steve Stevens"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/415","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ab5"}},{"Key":"albums/416","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Beyond Good And Evil","CountSold":0,"Artist":{"Id":"artists/139","Name":"The Cult"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/416","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ab6"}},{"Key":"albums/418","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"The Doors","CountSold":0,"Artist":{"Id":"artists/140","Name":"The Doors"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/418","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ab7"}},{"Key":"albums/419","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"The Police Greatest Hits","CountSold":0,"Artist":{"Id":"artists/141","Name":"The Police"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/419","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ab8"}},{"Key":"albums/420","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Hot Rocks, 1964-1971 (Disc 1)","CountSold":0,"Artist":{"Id":"artists/142","Name":"The Rolling Stones"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/420","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ab9"}},{"Key":"albums/421","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"No Security","CountSold":0,"Artist":{"Id":"artists/142","Name":"The Rolling Stones"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/421","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aba"}},{"Key":"albums/422","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Voodoo Lounge","CountSold":0,"Artist":{"Id":"artists/142","Name":"The Rolling Stones"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/422","@etag":"c6000000-00a0-bd66-11df-5fcfc1379abb"}},{"Key":"albums/423","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"My Generation - The Very Best Of The Who","CountSold":0,"Artist":{"Id":"artists/144","Name":"The Who"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/423","@etag":"c6000000-00a0-bd66-11df-5fcfc1379abc"}},{"Key":"albums/424","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Achtung Baby","CountSold":0,"Artist":{"Id":"artists/150","Name":"U2"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/424","@etag":"c6000000-00a0-bd66-11df-5fcfc1379abd"}},{"Key":"albums/425","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"B-Sides 1980-1990","CountSold":0,"Artist":{"Id":"artists/150","Name":"U2"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/425","@etag":"c6000000-00a0-bd66-11df-5fcfc1379abe"}},{"Key":"albums/426","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"How To Dismantle An Atomic Bomb","CountSold":0,"Artist":{"Id":"artists/150","Name":"U2"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/426","@etag":"c6000000-00a0-bd66-11df-5fcfc1379abf"}},{"Key":"albums/427","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Pop","CountSold":0,"Artist":{"Id":"artists/150","Name":"U2"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/427","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ac0"}},{"Key":"albums/428","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Rattle And Hum","CountSold":0,"Artist":{"Id":"artists/150","Name":"U2"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/428","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ac1"}},{"Key":"albums/429","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"The Best Of 1980-1990","CountSold":0,"Artist":{"Id":"artists/150","Name":"U2"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/429","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ac2"}},{"Key":"albums/430","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"War","CountSold":0,"Artist":{"Id":"artists/150","Name":"U2"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/430","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ac3"}},{"Key":"albums/431","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Zooropa","CountSold":0,"Artist":{"Id":"artists/150","Name":"U2"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/431","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ac4"}},{"Key":"albums/432","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Diver Down","CountSold":0,"Artist":{"Id":"artists/152","Name":"Van Halen"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/432","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ac5"}},{"Key":"albums/433","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"The Best Of Van Halen, Vol. I","CountSold":0,"Artist":{"Id":"artists/152","Name":"Van Halen"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/433","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ac6"}},{"Key":"albums/434","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Van Halen III","CountSold":0,"Artist":{"Id":"artists/152","Name":"Van Halen"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/434","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ac7"}},{"Key":"albums/435","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Van Halen","CountSold":0,"Artist":{"Id":"artists/152","Name":"Van Halen"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/435","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ac8"}},{"Key":"albums/436","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Contraband","CountSold":0,"Artist":{"Id":"artists/153","Name":"Velvet Revolver"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/436","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ac9"}},{"Key":"albums/437","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Un-Led-Ed","CountSold":0,"Artist":{"Id":"artists/157","Name":"Dread Zeppelin"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/437","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aca"}},{"Key":"albums/439","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Balls to the Wall","CountSold":0,"Artist":{"Id":"artists/2","Name":"Accept"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/439","@etag":"c6000000-00a0-bd66-11df-5fcfc1379acb"}},{"Key":"albums/440","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Restless and Wild","CountSold":0,"Artist":{"Id":"artists/2","Name":"Accept"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/440","@etag":"c6000000-00a0-bd66-11df-5fcfc1379acc"}},{"Key":"albums/441","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Every Kind of Light","CountSold":0,"Artist":{"Id":"artists/200","Name":"The Posies"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/441","@etag":"c6000000-00a0-bd66-11df-5fcfc1379acd"}},{"Key":"albums/442","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"BBC Sessions [Disc 1] [Live]","CountSold":0,"Artist":{"Id":"artists/22","Name":"Led Zeppelin"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/442","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ace"}},{"Key":"albums/443","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"BBC Sessions [Disc 2] [Live]","CountSold":0,"Artist":{"Id":"artists/22","Name":"Led Zeppelin"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/443","@etag":"c6000000-00a0-bd66-11df-5fcfc1379acf"}},{"Key":"albums/444","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Coda","CountSold":0,"Artist":{"Id":"artists/22","Name":"Led Zeppelin"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/444","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ad0"}},{"Key":"albums/445","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Houses Of The Holy","CountSold":0,"Artist":{"Id":"artists/22","Name":"Led Zeppelin"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/445","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ad1"}},{"Key":"albums/446","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"In Through The Out Door","CountSold":0,"Artist":{"Id":"artists/22","Name":"Led Zeppelin"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/446","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ad2"}},{"Key":"albums/447","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"IV","CountSold":0,"Artist":{"Id":"artists/22","Name":"Led Zeppelin"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/447","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ad3"}},{"Key":"albums/448","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Led Zeppelin I","CountSold":0,"Artist":{"Id":"artists/22","Name":"Led Zeppelin"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/448","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ad4"}},{"Key":"albums/449","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Led Zeppelin II","CountSold":0,"Artist":{"Id":"artists/22","Name":"Led Zeppelin"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/449","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ad5"}},{"Key":"albums/450","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Led Zeppelin III","CountSold":0,"Artist":{"Id":"artists/22","Name":"Led Zeppelin"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/450","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ad6"}},{"Key":"albums/451","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Physical Graffiti [Disc 1]","CountSold":0,"Artist":{"Id":"artists/22","Name":"Led Zeppelin"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/451","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ad7"}},{"Key":"albums/452","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Physical Graffiti [Disc 2]","CountSold":0,"Artist":{"Id":"artists/22","Name":"Led Zeppelin"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/452","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ad8"}},{"Key":"albums/453","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Presence","CountSold":0,"Artist":{"Id":"artists/22","Name":"Led Zeppelin"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/453","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ad9"}},{"Key":"albums/454","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"The Song Remains The Same (Disc 1)","CountSold":0,"Artist":{"Id":"artists/22","Name":"Led Zeppelin"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/454","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ada"}},{"Key":"albums/455","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"The Song Remains The Same (Disc 2)","CountSold":0,"Artist":{"Id":"artists/22","Name":"Led Zeppelin"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/455","@etag":"c6000000-00a0-bd66-11df-5fcfc1379adb"}},{"Key":"albums/456","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Bongo Fury","CountSold":0,"Artist":{"Id":"artists/23","Name":"Frank Zappa & Captain Beefheart"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/456","@etag":"c6000000-00a0-bd66-11df-5fcfc1379adc"}},{"Key":"albums/457","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Big Ones","CountSold":0,"Artist":{"Id":"artists/3","Name":"Aerosmith"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/457","@etag":"c6000000-00a0-bd66-11df-5fcfc1379add"}},{"Key":"albums/458","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Jagged Little Pill","CountSold":0,"Artist":{"Id":"artists/4","Name":"Alanis Morissette"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/458","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ade"}},{"Key":"albums/459","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Facelift","CountSold":0,"Artist":{"Id":"artists/5","Name":"Alice In Chains"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/459","@etag":"c6000000-00a0-bd66-11df-5fcfc1379adf"}},{"Key":"albums/460","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Greatest Hits I","CountSold":0,"Artist":{"Id":"artists/51","Name":"Queen"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/460","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ae0"}},{"Key":"albums/461","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Greatest Hits II","CountSold":0,"Artist":{"Id":"artists/51","Name":"Queen"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/461","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ae1"}},{"Key":"albums/462","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"News Of The World","CountSold":0,"Artist":{"Id":"artists/51","Name":"Queen"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/462","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ae2"}},{"Key":"albums/463","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Greatest Kiss","CountSold":0,"Artist":{"Id":"artists/52","Name":"Kiss"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/463","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ae3"}},{"Key":"albums/464","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Unplugged [Live]","CountSold":0,"Artist":{"Id":"artists/52","Name":"Kiss"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/464","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ae4"}},{"Key":"albums/465","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Into The Light","CountSold":0,"Artist":{"Id":"artists/55","Name":"David Coverdale"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/465","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ae5"}},{"Key":"albums/466","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Come Taste The Band","CountSold":0,"Artist":{"Id":"artists/58","Name":"Deep Purple"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/466","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ae6"}},{"Key":"albums/467","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Deep Purple In Rock","CountSold":0,"Artist":{"Id":"artists/58","Name":"Deep Purple"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/467","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ae7"}},{"Key":"albums/468","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Fireball","CountSold":0,"Artist":{"Id":"artists/58","Name":"Deep Purple"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/468","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ae8"}},{"Key":"albums/469","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Machine Head","CountSold":0,"Artist":{"Id":"artists/58","Name":"Deep Purple"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/469","@etag":"c6000000-00a0-bd66-11df-5fcfc1379ae9"}},{"Key":"albums/470","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"MK III The Final Concerts [Disc 1]","CountSold":0,"Artist":{"Id":"artists/58","Name":"Deep Purple"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/470","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aea"}},{"Key":"albums/471","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Purpendicular","CountSold":0,"Artist":{"Id":"artists/58","Name":"Deep Purple"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/471","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aeb"}},{"Key":"albums/472","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Slaves And Masters","CountSold":0,"Artist":{"Id":"artists/58","Name":"Deep Purple"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/472","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aec"}},{"Key":"albums/473","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Stormbringer","CountSold":0,"Artist":{"Id":"artists/58","Name":"Deep Purple"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/473","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aed"}},{"Key":"albums/474","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"The Battle Rages On","CountSold":0,"Artist":{"Id":"artists/58","Name":"Deep Purple"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/474","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aee"}},{"Key":"albums/475","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"The Final Concerts (Disc 2)","CountSold":0,"Artist":{"Id":"artists/58","Name":"Deep Purple"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/475","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aef"}},{"Key":"albums/476","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Santana - As Years Go By","CountSold":0,"Artist":{"Id":"artists/59","Name":"Santana"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/476","@etag":"c6000000-00a0-bd66-11df-5fcfc1379af0"}},{"Key":"albums/477","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Santana Live","CountSold":0,"Artist":{"Id":"artists/59","Name":"Santana"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/477","@etag":"c6000000-00a0-bd66-11df-5fcfc1379af1"}},{"Key":"albums/478","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Supernatural","CountSold":0,"Artist":{"Id":"artists/59","Name":"Santana"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/478","@etag":"c6000000-00a0-bd66-11df-5fcfc1379af2"}},{"Key":"albums/479","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Chronicle, Vol. 1","CountSold":0,"Artist":{"Id":"artists/76","Name":"Creedence Clearwater Revival"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/479","@etag":"c6000000-00a0-bd66-11df-5fcfc1379af3"}},{"Key":"albums/480","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Chronicle, Vol. 2","CountSold":0,"Artist":{"Id":"artists/76","Name":"Creedence Clearwater Revival"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/480","@etag":"c6000000-00a0-bd66-11df-5fcfc1379af4"}},{"Key":"albums/481","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Audioslave","CountSold":0,"Artist":{"Id":"artists/8","Name":"Audioslave"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/481","@etag":"c6000000-00a0-bd66-11df-5fcfc1379af5"}},{"Key":"albums/482","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"King For A Day Fool For A Lifetime","CountSold":0,"Artist":{"Id":"artists/82","Name":"Faith No More"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/482","@etag":"c6000000-00a0-bd66-11df-5fcfc1379af6"}},{"Key":"albums/483","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"In Your Honor [Disc 1]","CountSold":0,"Artist":{"Id":"artists/84","Name":"Foo Fighters"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/483","@etag":"c6000000-00a0-bd66-11df-5fcfc1379af7"}},{"Key":"albums/484","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"In Your Honor [Disc 2]","CountSold":0,"Artist":{"Id":"artists/84","Name":"Foo Fighters"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/484","@etag":"c6000000-00a0-bd66-11df-5fcfc1379af8"}},{"Key":"albums/485","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"The Colour And The Shape","CountSold":0,"Artist":{"Id":"artists/84","Name":"Foo Fighters"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/485","@etag":"c6000000-00a0-bd66-11df-5fcfc1379af9"}},{"Key":"albums/486","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Appetite for Destruction","CountSold":0,"Artist":{"Id":"artists/88","Name":"Guns N' Roses"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/486","@etag":"c6000000-00a0-bd66-11df-5fcfc1379afa"}},{"Key":"albums/487","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Use Your Illusion I","CountSold":0,"Artist":{"Id":"artists/88","Name":"Guns N' Roses"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/487","@etag":"c6000000-00a0-bd66-11df-5fcfc1379afb"}},{"Key":"albums/488","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"A Matter of Life and Death","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/488","@etag":"c6000000-00a0-bd66-11df-5fcfc1379afc"}},{"Key":"albums/489","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Brave New World","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/489","@etag":"c6000000-00a0-bd66-11df-5fcfc1379afd"}},{"Key":"albums/490","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Fear Of The Dark","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/490","@etag":"c6000000-00a0-bd66-11df-5fcfc1379afe"}},{"Key":"albums/491","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Live At Donington 1992 (Disc 1)","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/491","@etag":"c6000000-00a0-bd66-11df-5fcfc1379aff"}},{"Key":"albums/492","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Live At Donington 1992 (Disc 2)","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/492","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b00"}},{"Key":"albums/493","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Rock In Rio [CD2]","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/493","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b01"}},{"Key":"albums/494","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"The Number of The Beast","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/494","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b02"}},{"Key":"albums/495","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"The X Factor","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/495","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b03"}},{"Key":"albums/496","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Virtual XI","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/496","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b04"}},{"Key":"albums/497","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Emergency On Planet Earth","CountSold":0,"Artist":{"Id":"artists/92","Name":"Jamiroquai"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/497","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b05"}},{"Key":"albums/498","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Are You Experienced?","CountSold":0,"Artist":{"Id":"artists/94","Name":"Jimi Hendrix"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/498","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b06"}},{"Key":"albums/499","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Surfing with the Alien (Remastered)","CountSold":0,"Artist":{"Id":"artists/95","Name":"Joe Satriani"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/499","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b07"}},{"Key":"albums/500","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"The Best of Beethoven","CountSold":0,"Artist":{"Id":"artists/203","Name":"Nicolaus Esterhazy Sinfonia"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/500","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b08"}},{"Key":"albums/504","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Pachelbel: Canon & Gigue","CountSold":0,"Artist":{"Id":"artists/208","Name":"English Concert & Trevor Pinnock"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/504","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b09"}},{"Key":"albums/507","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Bach: Goldberg Variations","CountSold":0,"Artist":{"Id":"artists/211","Name":"Wilhelm Kempff"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/507","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b0a"}},{"Key":"albums/508","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Bach: The Cello Suites","CountSold":0,"Artist":{"Id":"artists/212","Name":"Yo-Yo Ma"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/508","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b0b"}},{"Key":"albums/509","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Handel: The Messiah (Highlights)","CountSold":0,"Artist":{"Id":"artists/213","Name":"Scholars Baroque Ensemble"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/509","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b0c"}},{"Key":"albums/513","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Haydn: Symphonies 99 - 104","CountSold":0,"Artist":{"Id":"artists/217","Name":"Royal Philharmonic Orchestra & Sir Thomas Beecham"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/513","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b0d"}},{"Key":"albums/515","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"A Soprano Inspired","CountSold":0,"Artist":{"Id":"artists/219","Name":"Britten Sinfonia, Ivor Bolton & Lesley Garrett"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/515","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b0e"}},{"Key":"albums/517","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Wagner: Favourite Overtures","CountSold":0,"Artist":{"Id":"artists/221","Name":"Sir Georg Solti & Wiener Philharmoniker"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/517","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b0f"}},{"Key":"albums/519","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Tchaikovsky: The Nutcracker","CountSold":0,"Artist":{"Id":"artists/223","Name":"London Symphony Orchestra & Sir Charles Mackerras"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/519","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b10"}},{"Key":"albums/520","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"The Last Night of the Proms","CountSold":0,"Artist":{"Id":"artists/224","Name":"Barry Wordsworth & BBC Concert Orchestra"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/520","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b11"}},{"Key":"albums/523","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Respighi:Pines of Rome","CountSold":0,"Artist":{"Id":"artists/226","Name":"Eugene Ormandy"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/523","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b12"}},{"Key":"albums/524","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Strauss: Waltzes","CountSold":0,"Artist":{"Id":"artists/226","Name":"Eugene Ormandy"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/524","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b13"}},{"Key":"albums/525","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Carmina Burana","CountSold":0,"Artist":{"Id":"artists/229","Name":"Boston Symphony Orchestra & Seiji Ozawa"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/525","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b14"}},{"Key":"albums/526","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"A Copland Celebration, Vol. I","CountSold":0,"Artist":{"Id":"artists/230","Name":"Aaron Copland & London Symphony Orchestra"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/526","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b15"}},{"Key":"albums/527","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Bach: Toccata & Fugue in D Minor","CountSold":0,"Artist":{"Id":"artists/231","Name":"Ton Koopman"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/527","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b16"}},{"Key":"albums/528","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Prokofiev: Symphony No.1","CountSold":0,"Artist":{"Id":"artists/232","Name":"Sergei Prokofiev & Yuri Temirkanov"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/528","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b17"}},{"Key":"albums/529","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Scheherazade","CountSold":0,"Artist":{"Id":"artists/233","Name":"Chicago Symphony Orchestra & Fritz Reiner"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/529","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b18"}},{"Key":"albums/530","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Bach: The Brandenburg Concertos","CountSold":0,"Artist":{"Id":"artists/234","Name":"Orchestra of The Age of Enlightenment"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/530","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b19"}},{"Key":"albums/532","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Mascagni: Cavalleria Rusticana","CountSold":0,"Artist":{"Id":"artists/236","Name":"James Levine"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/532","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b1a"}},{"Key":"albums/533","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Sibelius: Finlandia","CountSold":0,"Artist":{"Id":"artists/237","Name":"Berliner Philharmoniker & Hans Rosbaud"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/533","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b1b"}},{"Key":"albums/537","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Adams, John: The Chairman Dances","CountSold":0,"Artist":{"Id":"artists/242","Name":"Edo de Waart & San Francisco Symphony"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/537","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b1c"}},{"Key":"albums/539","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Berlioz: Symphonie Fantastique","CountSold":0,"Artist":{"Id":"artists/245","Name":"Michael Tilson Thomas & San Francisco Symphony"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/539","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b1d"}},{"Key":"albums/540","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Prokofiev: Romeo & Juliet","CountSold":0,"Artist":{"Id":"artists/245","Name":"Michael Tilson Thomas & San Francisco Symphony"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/540","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b1e"}},{"Key":"albums/542","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"English Renaissance","CountSold":0,"Artist":{"Id":"artists/247","Name":"The King's Singers"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/542","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b1f"}},{"Key":"albums/544","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Mozart: Symphonies Nos. 40 & 41","CountSold":0,"Artist":{"Id":"artists/248","Name":"Berliner Philharmoniker & Herbert Von Karajan"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/544","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b20"}},{"Key":"albums/546","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"SCRIABIN: Vers la flamme","CountSold":0,"Artist":{"Id":"artists/250","Name":"Christopher O'Riley"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/546","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b21"}},{"Key":"albums/548","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Bartok: Violin & Viola Concertos","CountSold":0,"Artist":{"Id":"artists/255","Name":"Yehudi Menuhin"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/548","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b22"}},{"Key":"albums/551","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"South American Getaway","CountSold":0,"Artist":{"Id":"artists/259","Name":"The 12 Cellists of The Berlin Philharmonic"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/551","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b23"}},{"Key":"albums/552","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Górecki: Symphony No. 3","CountSold":0,"Artist":{"Id":"artists/260","Name":"Adrian Leaper & Doreen de Feis"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/552","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b24"}},{"Key":"albums/553","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Purcell: The Fairy Queen","CountSold":0,"Artist":{"Id":"artists/261","Name":"Roger Norrington, London Classical Players"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/553","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b25"}},{"Key":"albums/556","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Weill: The Seven Deadly Sins","CountSold":0,"Artist":{"Id":"artists/264","Name":"Kent Nagano and Orchestre de l'Opéra de Lyon"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/556","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b26"}},{"Key":"albums/558","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Szymanowski: Piano Works, Vol. 1","CountSold":0,"Artist":{"Id":"artists/266","Name":"Martin Roscoe"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/558","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b27"}},{"Key":"albums/559","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Nielsen: The Six Symphonies","CountSold":0,"Artist":{"Id":"artists/267","Name":"Göteborgs Symfoniker & Neeme Järvi"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/559","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b28"}},{"Key":"albums/562","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/10","Name":"Classical"},"Price":8.99,"Title":"Mozart: Chamber Music","CountSold":0,"Artist":{"Id":"artists/274","Name":"Nash Ensemble"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/562","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b29"}},{"Key":"albums/563","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/2","Name":"Jazz"},"Price":8.99,"Title":"The Best Of Billy Cobham","CountSold":0,"Artist":{"Id":"artists/10","Name":"Billy Cobham"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/563","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b2a"}},{"Key":"albums/564","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/2","Name":"Jazz"},"Price":8.99,"Title":"Quiet Songs","CountSold":0,"Artist":{"Id":"artists/197","Name":"Aisha Duo"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/564","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b2b"}},{"Key":"albums/565","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/2","Name":"Jazz"},"Price":8.99,"Title":"Worlds","CountSold":0,"Artist":{"Id":"artists/202","Name":"Aaron Goldberg"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/565","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b2c"}},{"Key":"albums/566","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/2","Name":"Jazz"},"Price":8.99,"Title":"Quanta Gente Veio ver--Bônus De Carnaval","CountSold":0,"Artist":{"Id":"artists/27","Name":"Gilberto Gil"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/566","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b2d"}},{"Key":"albums/567","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/2","Name":"Jazz"},"Price":8.99,"Title":"Heart of the Night","CountSold":0,"Artist":{"Id":"artists/53","Name":"Spyro Gyra"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/567","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b2e"}},{"Key":"albums/568","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/2","Name":"Jazz"},"Price":8.99,"Title":"Morning Dance","CountSold":0,"Artist":{"Id":"artists/53","Name":"Spyro Gyra"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/568","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b2f"}},{"Key":"albums/569","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/2","Name":"Jazz"},"Price":8.99,"Title":"Warner 25 Anos","CountSold":0,"Artist":{"Id":"artists/6","Name":"Antônio Carlos Jobim"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/569","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b30"}},{"Key":"albums/570","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/2","Name":"Jazz"},"Price":8.99,"Title":"Miles Ahead","CountSold":0,"Artist":{"Id":"artists/68","Name":"Miles Davis"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/570","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b31"}},{"Key":"albums/571","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/2","Name":"Jazz"},"Price":8.99,"Title":"The Essential Miles Davis [Disc 1]","CountSold":0,"Artist":{"Id":"artists/68","Name":"Miles Davis"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/571","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b32"}},{"Key":"albums/572","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/2","Name":"Jazz"},"Price":8.99,"Title":"The Essential Miles Davis [Disc 2]","CountSold":0,"Artist":{"Id":"artists/68","Name":"Miles Davis"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/572","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b33"}},{"Key":"albums/573","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/2","Name":"Jazz"},"Price":8.99,"Title":"Outbreak","CountSold":0,"Artist":{"Id":"artists/79","Name":"Dennis Chambers"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/573","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b34"}},{"Key":"albums/574","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/2","Name":"Jazz"},"Price":8.99,"Title":"Blue Moods","CountSold":0,"Artist":{"Id":"artists/89","Name":"Incognito"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/574","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b35"}},{"Key":"albums/575","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Greatest Hits","CountSold":0,"Artist":{"Id":"artists/100","Name":"Lenny Kravitz"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/575","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b36"}},{"Key":"albums/579","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Alcohol Fueled Brewtality Live! [Disc 2]","CountSold":0,"Artist":{"Id":"artists/11","Name":"Black Label Society"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/579","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b3a"}},{"Key":"albums/580","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Tribute","CountSold":0,"Artist":{"Id":"artists/114","Name":"Ozzy Osbourne"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/580","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b3b"}},{"Key":"albums/581","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Black Sabbath Vol. 4 (Remaster)","CountSold":0,"Artist":{"Id":"artists/12","Name":"Black Sabbath"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/581","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b3c"}},{"Key":"albums/582","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Black Sabbath","CountSold":0,"Artist":{"Id":"artists/12","Name":"Black Sabbath"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/582","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b3d"}},{"Key":"albums/583","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Mezmerize","CountSold":0,"Artist":{"Id":"artists/135","Name":"System Of A Down"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/583","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b3e"}},{"Key":"albums/584","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Chemical Wedding","CountSold":0,"Artist":{"Id":"artists/14","Name":"Bruce Dickinson"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/584","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b3f"}},{"Key":"albums/585","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"...And Justice For All","CountSold":0,"Artist":{"Id":"artists/50","Name":"Metallica"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/585","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b40"}},{"Key":"albums/586","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Black Album","CountSold":0,"Artist":{"Id":"artists/50","Name":"Metallica"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/586","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b41"}},{"Key":"albums/587","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Garage Inc. (Disc 1)","CountSold":0,"Artist":{"Id":"artists/50","Name":"Metallica"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/587","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b42"}},{"Key":"albums/588","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Garage Inc. (Disc 2)","CountSold":0,"Artist":{"Id":"artists/50","Name":"Metallica"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/588","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b43"}},{"Key":"albums/589","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Load","CountSold":0,"Artist":{"Id":"artists/50","Name":"Metallica"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/589","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b44"}},{"Key":"albums/590","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Master Of Puppets","CountSold":0,"Artist":{"Id":"artists/50","Name":"Metallica"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/590","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b45"}},{"Key":"albums/591","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"ReLoad","CountSold":0,"Artist":{"Id":"artists/50","Name":"Metallica"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/591","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b46"}},{"Key":"albums/592","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Ride The Lightning","CountSold":0,"Artist":{"Id":"artists/50","Name":"Metallica"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/592","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b47"}},{"Key":"albums/593","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"St. Anger","CountSold":0,"Artist":{"Id":"artists/50","Name":"Metallica"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/593","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b48"}},{"Key":"albums/594","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Plays Metallica By Four Cellos","CountSold":0,"Artist":{"Id":"artists/7","Name":"Apocalyptica"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/594","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b49"}},{"Key":"albums/595","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Faceless","CountSold":0,"Artist":{"Id":"artists/87","Name":"Godsmack"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/595","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b4a"}},{"Key":"albums/596","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Use Your Illusion II","CountSold":0,"Artist":{"Id":"artists/88","Name":"Guns N' Roses"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/596","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b4b"}},{"Key":"albums/597","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"A Real Dead One","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/597","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b4c"}},{"Key":"albums/598","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"A Real Live One","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/598","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b4d"}},{"Key":"albums/599","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Live After Death","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/599","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b4e"}},{"Key":"albums/600","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"No Prayer For The Dying","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/600","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b4f"}},{"Key":"albums/601","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Piece Of Mind","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/601","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b50"}},{"Key":"albums/602","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Powerslave","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/602","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b51"}},{"Key":"albums/603","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Rock In Rio [CD1]","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/603","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b52"}},{"Key":"albums/604","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Rock In Rio [CD2]","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/604","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b53"}},{"Key":"albums/605","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Seventh Son of a Seventh Son","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/605","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b54"}},{"Key":"albums/606","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Somewhere in Time","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/606","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b55"}},{"Key":"albums/607","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"The Number of The Beast","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/607","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b56"}},{"Key":"albums/608","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Living After Midnight","CountSold":0,"Artist":{"Id":"artists/98","Name":"Judas Priest"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/608","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b57"}},{"Key":"albums/613","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/4","Name":"Alternative"},"Price":8.99,"Title":"Revelations","CountSold":0,"Artist":{"Id":"artists/8","Name":"Audioslave"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/613","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b5c"}},{"Key":"albums/618","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/6","Name":"Blues"},"Price":8.99,"Title":"The Cream Of Clapton","CountSold":0,"Artist":{"Id":"artists/81","Name":"Eric Clapton"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/618","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b60"}},{"Key":"albums/619","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/6","Name":"Blues"},"Price":8.99,"Title":"Unplugged","CountSold":0,"Artist":{"Id":"artists/81","Name":"Eric Clapton"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/619","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b61"}},{"Key":"albums/620","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/6","Name":"Blues"},"Price":8.99,"Title":"Iron Maiden","CountSold":0,"Artist":{"Id":"artists/90","Name":"Iron Maiden"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/620","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b62"}},{"Key":"albums/623","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Barulhinho Bom","CountSold":0,"Artist":{"Id":"artists/103","Name":"Marisa Monte"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/623","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b63"}},{"Key":"albums/624","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Olodum","CountSold":0,"Artist":{"Id":"artists/112","Name":"Olodum"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/624","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b64"}},{"Key":"albums/625","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Acústico MTV","CountSold":0,"Artist":{"Id":"artists/113","Name":"Os Paralamas Do Sucesso"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/625","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b65"}},{"Key":"albums/627","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Arquivo Os Paralamas Do Sucesso","CountSold":0,"Artist":{"Id":"artists/113","Name":"Os Paralamas Do Sucesso"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/627","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b67"}},{"Key":"albums/628","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Serie Sem Limite (Disc 1)","CountSold":0,"Artist":{"Id":"artists/145","Name":"Tim Maia"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/628","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b68"}},{"Key":"albums/630","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Ao Vivo [IMPORT]","CountSold":0,"Artist":{"Id":"artists/155","Name":"Zeca Pagodinho"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/630","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b6a"}},{"Key":"albums/631","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Prenda Minha","CountSold":0,"Artist":{"Id":"artists/16","Name":"Caetano Veloso"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/631","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b6b"}},{"Key":"albums/632","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Sozinho Remix Ao Vivo","CountSold":0,"Artist":{"Id":"artists/16","Name":"Caetano Veloso"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/632","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b6c"}},{"Key":"albums/633","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Minha Historia","CountSold":0,"Artist":{"Id":"artists/17","Name":"Chico Buarque"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/633","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b6d"}},{"Key":"albums/634","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Afrociberdelia","CountSold":0,"Artist":{"Id":"artists/18","Name":"Chico Science & Nação Zumbi"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/634","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b6e"}},{"Key":"albums/635","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Da Lama Ao Caos","CountSold":0,"Artist":{"Id":"artists/18","Name":"Chico Science & Nação Zumbi"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/635","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b6f"}},{"Key":"albums/636","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Na Pista","CountSold":0,"Artist":{"Id":"artists/20","Name":"Cláudio Zoli"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/636","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b70"}},{"Key":"albums/637","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Duos II","CountSold":0,"Artist":{"Id":"artists/201","Name":"Luciana Souza/Romero Lubambo"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/637","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b71"}},{"Key":"albums/638","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Sambas De Enredo 2001","CountSold":0,"Artist":{"Id":"artists/21","Name":"Various Artists"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/638","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b72"}},{"Key":"albums/639","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Vozes do MPB","CountSold":0,"Artist":{"Id":"artists/21","Name":"Various Artists"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/639","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b73"}},{"Key":"albums/640","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Chill: Brazil (Disc 1)","CountSold":0,"Artist":{"Id":"artists/24","Name":"Marcos Valle"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/640","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b74"}},{"Key":"albums/641","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Quanta Gente Veio Ver (Live)","CountSold":0,"Artist":{"Id":"artists/27","Name":"Gilberto Gil"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/641","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b75"}},{"Key":"albums/642","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"The Best of Ed Motta","CountSold":0,"Artist":{"Id":"artists/37","Name":"Ed Motta"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/642","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b76"}},{"Key":"albums/643","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Elis Regina-Minha História","CountSold":0,"Artist":{"Id":"artists/41","Name":"Elis Regina"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/643","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b77"}},{"Key":"albums/644","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Milton Nascimento Ao Vivo","CountSold":0,"Artist":{"Id":"artists/42","Name":"Milton Nascimento"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/644","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b78"}},{"Key":"albums/645","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Minas","CountSold":0,"Artist":{"Id":"artists/42","Name":"Milton Nascimento"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/645","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b79"}},{"Key":"albums/646","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Jorge Ben Jor 25 Anos","CountSold":0,"Artist":{"Id":"artists/46","Name":"Jorge Ben"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/646","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b7a"}},{"Key":"albums/647","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Meus Momentos","CountSold":0,"Artist":{"Id":"artists/56","Name":"Gonzaguinha"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/647","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b7b"}},{"Key":"albums/648","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Chill: Brazil (Disc 2)","CountSold":0,"Artist":{"Id":"artists/6","Name":"Antônio Carlos Jobim"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/648","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b7c"}},{"Key":"albums/649","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Vinicius De Moraes","CountSold":0,"Artist":{"Id":"artists/72","Name":"Vinícius De Moraes"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/649","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b7d"}},{"Key":"albums/651","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Cássia Eller - Sem Limite [Disc 1]","CountSold":0,"Artist":{"Id":"artists/77","Name":"Cássia Eller"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/651","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b7e"}},{"Key":"albums/652","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Djavan Ao Vivo - Vol. 02","CountSold":0,"Artist":{"Id":"artists/80","Name":"Djavan"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/652","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b7f"}},{"Key":"albums/653","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Djavan Ao Vivo - Vol. 1","CountSold":0,"Artist":{"Id":"artists/80","Name":"Djavan"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/653","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b80"}},{"Key":"albums/654","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Unplugged","CountSold":0,"Artist":{"Id":"artists/81","Name":"Eric Clapton"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/654","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b81"}},{"Key":"albums/655","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Deixa Entrar","CountSold":0,"Artist":{"Id":"artists/83","Name":"Falamansa"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/655","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b82"}},{"Key":"albums/656","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Roda De Funk","CountSold":0,"Artist":{"Id":"artists/86","Name":"Funk Como Le Gusta"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/656","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b83"}},{"Key":"albums/657","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Jota Quest-1995","CountSold":0,"Artist":{"Id":"artists/96","Name":"Jota Quest"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/657","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b84"}},{"Key":"albums/659","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Mais Do Mesmo","CountSold":0,"Artist":{"Id":"artists/99","Name":"Legião Urbana"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/659","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b85"}},{"Key":"albums/662","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/8","Name":"Reggae"},"Price":8.99,"Title":"Acústico MTV [Live]","CountSold":0,"Artist":{"Id":"artists/19","Name":"Cidade Negra"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/662","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b88"}},{"Key":"albums/663","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/8","Name":"Reggae"},"Price":8.99,"Title":"Cidade Negra - Hits","CountSold":0,"Artist":{"Id":"artists/19","Name":"Cidade Negra"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/663","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b89"}},{"Key":"albums/665","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/9","Name":"Pop"},"Price":8.99,"Title":"Axé Bahia 2001","CountSold":0,"Artist":{"Id":"artists/21","Name":"Various Artists"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/665","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b8a"}},{"Key":"albums/666","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/9","Name":"Pop"},"Price":8.99,"Title":"Frank","CountSold":0,"Artist":{"Id":"artists/252","Name":"Amy Winehouse"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/666","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b8b"}},{"Key":"albums/667","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/5","Name":"Disco"},"Price":8.99,"Title":"Le Freak","CountSold":0,"Artist":{"Id":"artists/276","Name":"Chic"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/667","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b8c"}},{"Key":"albums/668","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/5","Name":"Disco"},"Price":8.99,"Title":"MacArthur Park Suite","CountSold":0,"Artist":{"Id":"artists/278","Name":"Donna Summer"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/668","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b8d"}},{"Key":"albums/669","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Genre":{"Id":"genres/5","Name":"Disco"},"Price":8.99,"Title":"Ring My Bell","CountSold":0,"Artist":{"Id":"artists/277","Name":"Anita Ward"}},"Metadata":{"Raven-Entity-Name":"Albums","Last-Modified":"Sat, 15 May 2010 03:12:56 GMT","Raven-Clr-Type":"MvcMusicStore.Models.Album, Raven.Sample.SimpleClient","@id":"albums/669","@etag":"c6000000-00a0-bd66-11df-5fcfc1379b8e"}},{"Key":"albums/615","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/137","Name":"The Black Crowes"},"Genre":{"Id":"genres/6","Name":"Blues"},"Price":8.99,"Title":"Live [Disc 1]","CountSold":0},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 10:45:05 GMT","@id":"albums/615","@etag":"c6000000-00a0-bd66-11df-600eeb848ad0"}},{"Key":"albums/576","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/106","Name":"Motörhead"},"Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Ace Of Spades","CountSold":0},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 10:46:11 GMT","@id":"albums/576","@etag":"c6000000-00a0-bd66-11df-600f133d94b7"}},{"Key":"albums/577","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/109","Name":"Mötley Crüe"},"Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Motley Crue Greatest Hits","CountSold":0},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 10:47:11 GMT","@id":"albums/577","@etag":"c6000000-00a0-bd66-11df-600f36a360e6"}},{"Key":"albums/610","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/204","Name":"Temple of the Dog"},"Genre":{"Id":"genres/4","Name":"Alternative"},"Price":8.99,"Title":"Temple of the Dog","CountSold":0},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 10:48:56 GMT","@id":"albums/610","@etag":"c6000000-00a0-bd66-11df-600f755dbb29"}},{"Key":"albums/660","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/100","Name":"Lenny Kravitz"},"Genre":{"Id":"genres/8","Name":"Reggae"},"Price":8.99,"Title":"Greatest Hits","CountSold":0},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 10:50:32 GMT","@id":"albums/660","@etag":"c6000000-00a0-bd66-11df-600fabf9dece"}},{"Key":"albums/390","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/105","Name":"Men At Work"},"Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"The Best Of Men At Work","CountSold":0},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 10:52:40 GMT","@id":"albums/390","@etag":"c6000000-00a0-bd66-11df-600ffaa4f62f"}},{"Key":"albums/611","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/205","Name":"Chris Cornell"},"Genre":{"Id":"genres/4","Name":"Alternative"},"Price":8.99,"Title":"Carry On","CountSold":3},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 10:53:45 GMT","@id":"albums/611","@etag":"c6000000-00a0-bd66-11df-601021c7150f"}},{"Key":"albums/612","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/253","Name":"Calexico"},"Genre":{"Id":"genres/4","Name":"Alternative"},"Price":8.99,"Title":"Carried to Dust (Bonus Track Version)","CountSold":0},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 10:56:55 GMT","@id":"albums/612","@etag":"c6000000-00a0-bd66-11df-60108d5f3ad0"}},{"Key":"albums/614","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/133","Name":"Stevie Ray Vaughan & Double Trouble"},"Genre":{"Id":"genres/6","Name":"Blues"},"Price":8.99,"Title":"In Step","CountSold":0},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 10:57:05 GMT","@id":"albums/614","@etag":"c6000000-00a0-bd66-11df-601093e8257f"}},{"Key":"albums/616","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/137","Name":"The Black Crowes"},"Genre":{"Id":"genres/6","Name":"Blues"},"Price":8.99,"Title":"Live [Disc 2]","CountSold":0},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 10:59:34 GMT","@id":"albums/616","@etag":"c6000000-00a0-bd66-11df-6010f1db8289"}},{"Key":"albums/609","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/196","Name":"Cake"},"Genre":{"Id":"genres/4","Name":"Alternative"},"Price":8.99,"Title":"Cake: B-Sides and Rarities","CountSold":0},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 11:00:33 GMT","@id":"albums/609","@etag":"c6000000-00a0-bd66-11df-60111131d1c1"}},{"Key":"albums/386","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/1","Name":"AC/DC"},"Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"For Those About To Rock We Salute You","CountSold":0},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 14:10:15 GMT","@id":"albums/386","@etag":"c6000000-00a0-bd66-11df-602b94c30136"}},{"Key":"albums/578","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/11","Name":"Black Label Society"},"Genre":{"Id":"genres/3","Name":"Metal"},"Price":8.99,"Title":"Alcohol Fueled Brewtality Live! [Disc 1]","CountSold":0},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 14:14:06 GMT","@id":"albums/578","@etag":"c6000000-00a0-bd66-11df-602c1ef9bc3c"}},{"Key":"albums/661","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/151","Name":"UB40"},"Genre":{"Id":"genres/8","Name":"Reggae"},"Price":8.99,"Title":"UB40 The Best Of - Volume Two [UK]","CountSold":0},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 14:14:12 GMT","@id":"albums/661","@etag":"c6000000-00a0-bd66-11df-602c1ef9bc3e"}},{"Key":"albums/629","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/145","Name":"Tim Maia"},"Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Serie Sem Limite (Disc 2)","CountSold":0},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 14:15:08 GMT","@id":"albums/629","@etag":"c6000000-00a0-bd66-11df-602c43b161be"}},{"Key":"albums/393","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/111","Name":"O Terço"},"Genre":{"Id":"genres/1","Name":"Rock"},"Price":8.99,"Title":"Compositores","CountSold":0},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 15:11:59 GMT","@id":"albums/393","@etag":"c6000000-00a0-bd66-11df-60343505523f"}},{"Key":"albums/626","Method":"PUT","Document":{"AlbumArtUrl":"/Content/Images/placeholder.gif","Artist":{"Id":"artists/113","Name":"Os Paralamas Do Sucesso"},"Genre":{"Id":"genres/7","Name":"Latin"},"Price":8.99,"Title":"Arquivo II","CountSold":1},"Metadata":{"Raven-Entity-Name":"Albums","Raven-Clr-Type":"MvcMusicStore.Models.Album, Mvc Music Store","Content-Type":"application/json; charset=utf-8","Last-Modified":"Sat, 15 May 2010 15:15:09 GMT","@id":"albums/626","@etag":"c6000000-00a0-bd66-11df-6034a61da15d"}}],
      { },
      done);
  })
  it('should reset various test documents', function(done) {
    client.post('bulk_docs',
      { },
      [
        {"Key":"Raven/Hilo/TestDoc","Method":"DELETE"},
        {"Key":"Raven/Hilo/Album","Method":"DELETE"},
        {"Key":"Raven/Hilo/ServerHiTest","Method":"DELETE"},
        {"Key":"Raven/Hilo/MaxTest","Method":"DELETE"},
        {"Key":"Raven/Hilo/DashTest","Method":"DELETE"},
        {"Key":"Raven/Hilo/Store","Method":"DELETE"},
        {"Key":"Raven/Hilo/Artist","Method":"DELETE"}
      ],
      { },
      done);
  })
})
